Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(251)

Unified Diff: chrome/browser/sync/test/integration/two_client_sessions_sync_test.cc

Issue 8334030: Merge search engines sync data type with Preferences. Sync the default search provider. Add some ... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 9 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/test/integration/two_client_sessions_sync_test.cc
===================================================================
--- chrome/browser/sync/test/integration/two_client_sessions_sync_test.cc (revision 108653)
+++ chrome/browser/sync/test/integration/two_client_sessions_sync_test.cc (working copy)
@@ -160,10 +160,10 @@
ASSERT_TRUE(GetClient(1)->AwaitPassphraseRequired());
ASSERT_EQ(0, GetClient(1)->GetLastSessionSnapshot()->
num_blocking_conflicting_updates);
// We have 6 non-blocking conflicts due to the two meta nodes (one for each
// client), the one tab node, and the six basic preference/themes/search
// engines.
- ASSERT_EQ(9, GetClient(1)->GetLastSessionSnapshot()->
+ ASSERT_EQ(10, GetClient(1)->GetLastSessionSnapshot()->
Nicolas Zea 2011/11/04 23:08:06 bleh. Can we go ahead and add a helper method in s
SteveT 2011/11/07 21:48:56 All done, even though we unfortunately still have
num_conflicting_updates); // The encrypted nodes.
GetClient(1)->service()->SetPassphrase(kValidPassphrase, true);
@@ -242,8 +242,8 @@
ASSERT_EQ(0, GetClient(1)->GetLastSessionSnapshot()->
num_blocking_conflicting_updates);
// We have two non-blocking conflicts due to the two meta nodes (one for each
- // client), and the 6 basic preference/themes/search engines nodes.
- ASSERT_EQ(8, GetClient(1)->GetLastSessionSnapshot()->
+ // client), and the 7 basic preference/themes/search engines nodes.
+ ASSERT_EQ(9, GetClient(1)->GetLastSessionSnapshot()->
num_conflicting_updates); // The encrypted nodes.
// These changes are either made with the old passphrase or not encrypted at
@@ -254,7 +254,7 @@
ASSERT_TRUE(GetClient(1)->AwaitMutualSyncCycleCompletion(GetClient(0)));
ASSERT_EQ(0, GetClient(1)->GetLastSessionSnapshot()->
num_blocking_conflicting_updates);
- ASSERT_EQ(8, GetClient(1)->GetLastSessionSnapshot()->
+ ASSERT_EQ(9, GetClient(1)->GetLastSessionSnapshot()->
num_conflicting_updates); // The same encrypted nodes.
// At this point we enter the passphrase, triggering a resync, in which the
@@ -341,9 +341,9 @@
ASSERT_EQ(0, GetClient(1)->GetLastSessionSnapshot()->
num_blocking_conflicting_updates);
// We have three non-blocking conflicts due to the two meta nodes (one for
- // each client), the one tab node, and the 6 basic preference/themes/search
+ // each client), the one tab node, and the 7 basic preference/themes/search
// engines nodes.
- ASSERT_EQ(9, GetClient(1)->GetLastSessionSnapshot()->
+ ASSERT_EQ(10, GetClient(1)->GetLastSessionSnapshot()->
num_conflicting_updates); // The encrypted nodes.
GetClient(1)->service()->SetPassphrase(kValidPassphrase, true);
@@ -160,10 +160,10 @@
ASSERT_EQ(0, GetClient(1)->GetLastSessionSnapshot()->
num_blocking_conflicting_updates);
- // We have 6 non-blocking conflicts due to the two meta nodes (one for each
- // client), the one tab node, and the six basic preference/themes/search
+ // We have 10 non-blocking conflicts due to the two meta nodes (one for each
+ // client), the one tab node, and the seven basic preference/themes/search
// engines.

Powered by Google App Engine
This is Rietveld 408576698